@@ -12,6 +12,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <string.h>
 #include <errno.h>
 #include <sys/types.h>
@@ -333,12 +334,11 @@ static bool init_x(const char *display, int stflags)
     set_session(XDisplayName(display));
     
     wglobal.dpy=dpy;
-    
-    init_xim();
-    
-    wglobal.conn=ConnectionNumber(dpy);
     wglobal.win_context=XUniqueContext();
+    wglobal.conn=ConnectionNumber(dpy);
     
+    fcntl(wglobal.conn, F_SETFD, FD_CLOEXEC);
+
     wglobal.atom_wm_state=XInternAtom(dpy, "WM_STATE", False);
     wglobal.atom_wm_change_state=XInternAtom(dpy, "WM_CHANGE_STATE", False);
     wglobal.atom_wm_protocols=XInternAtom(dpy, "WM_PROTOCOLS", False);
@@ -351,6 +351,8 @@ static bool init_x(const char *display, int stflags)
     wglobal.atom_kludges=XInternAtom(dpy, "_ION_KLUDGES", False);
     wglobal.atom_mwm_hints=XInternAtom(dpy, "_MOTIF_WM_HINTS", False);
 
+    init_xim();
+
     netwm_init();
     
     init_bindings();
