@@ -28,6 +28,7 @@
 #include "regbind.h"
 #include "minmax.h"
 #include "genframe-pointer.h"
+#include "extlconv.h"
 
 
 #define SCR_MLIST(SCR) ((SCR)->mplex.managed_list)
@@ -459,6 +460,33 @@ void screen_set_managed_offset(WScreen *scr, const WRectangle *off)
 }
 
 
+/*EXTL_DOC
+ * Set offset of objects managed by the screen from actual screen geometry.
+ * The table \var{offset} should contain the entries \code{x}, \code{y}, 
+ * \code{w} and \code{h} indicating offsets of that component of screen 
+ * geometry.
+ */
+EXTL_EXPORT_MEMBER_AS(WScreen, set_managed_offset)
+bool screen_set_managed_offset_extl(WScreen *scr, ExtlTab offset)
+{
+    WRectangle g;
+    
+    if(!extltab_to_geom(offset, &g))
+        goto err;
+    
+    if(-g.w>=REGION_GEOM(scr).w)
+        goto err;
+    if(-g.h>=REGION_GEOM(scr).h)
+        goto err;
+    
+    screen_set_managed_offset(scr, &g);
+    
+    return TRUE;
+err:
+    warn("Invalid offset.");
+    return FALSE;
+}
+
 /*}}}*/
 
 
